import React, { Component, Fragment } from 'react'
import {
	Page, Validator, Notification, FormItem,
	InputItem, Input, Bind, SelectItem, Button, Label, DatePickerItem, Section, Table, TextArea, ConfirmButton, Steps
} from '@/components/Common-Library'
import Api from '@/service/api'
import mCptopn from '../model'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { action, observable } from 'mobx'
import Basic from './Basic'
import BaoSong from './BaoSong'
import ShenBao from './ShenBao'
import Fee from '@/views/Public/Fee'
import Gle from '@/views/Public/Gle'
import Papper from '@/views/Public/Papper'
import Mt103 from '@/views/Public/Mt103'
import Cmt100 from '@/views/Public/Cmt100'
import Fmt100 from '@/views/Public/Fmt100'
import Bspt from '@/views/Public/Bspt'
import Dbb from '@/views/Public/Dbb'
import Dbe from '@/views/Public/Dbe'
import Dbj from '@/views/Public/Dbj'
import Dbw from '@/views/Public/Dbw'

import { Card } from 'antd'

const StepItem = Steps.Item

@inject('UserContext')
@inject('i18n')
@observer
export default class CptopnScreen extends Page {
	@observable
	formBlur = false

	@observable
	extra = { inifrm: 'cptopn', sptinr: '', bchlevelLst: [] }

	constructor(props) {
		super(props)
		this.state = {
			flag: true
		}
		this.model = new mCptopn()
	}
	async componentWillMount() {
		let sptinr = '';
		let rtnmsg = [];
		if (this.props.location.query) {
			sptinr = this.props.location.query.inr
			this.extra.sptinr = sptinr
			rtnmsg = await Api.post(this.extra.inifrm + '/init', { params: { sptinr } })
		} else {
			rtnmsg = await Api.post(this.extra.inifrm + '/init', {})
		}
		if (rtnmsg.retcod == SUCCESS) {
			Object.assign(this.model, rtnmsg.data)
			this.extra.bchlevelLst = rtnmsg.codetable.branchinr;
			this.extra.bopmod_szflg = rtnmsg.codetable.bopmod_szflg;
			this.setState({ flag: false })
		}
		else {
			Notification.error({ message: '服务端请求失败!' })
		}

		//快照模式下，不必开启校验，否则，静默校验，和记录变动
		!this.loadDisplay() && this.model.openMonitor() //开启校验	
	}

	componentWillUnmount() {
		this.model.stopMonitor()//关闭校验
	}

	//清算路径
	onBaowen = () => {
		switch (this.model.swftyp) {
			case '103':
				return (<StepItem title="报文信息">
					<Mt103 model={this.model} extra={this.extra} />
				</StepItem>)
				break;
			case '103202':
				return [
						<StepItem title="报文信息(103)">
							<Mt103 model={this.model} extra={this.extra} />
						</StepItem>,
						<StepItem title="报文信息(202)">
							<Mt202 model={this.model} extra={this.extra} />
						</StepItem>
						]
						 
					break;
			case 'F01':
				return (<StepItem title="报文信息">
					<Mt103 model={this.model} extra={this.extra} />
				</StepItem>)
				break;
			case 'F00':
				return (<StepItem title="报文信息">
					<Fmt100 model={this.model} extra={this.extra} />
				</StepItem>)
				break;
			case 'CM0':
				return (<StepItem title="报文信息">
					<Cmt100 model={this.model} extra={this.extra} />
				</StepItem>)
				break;
			case 'C00'://cips 报文
				return (<StepItem title="报文信息">
					<Cmt100 model={this.model} extra={this.extra} />
				</StepItem>)
				break;
			case 'C01'://cips 报文
				return (<StepItem title="报文信息">
					<Cmt100 model={this.model} extra={this.extra} />
				</StepItem>)
				break;
			default:
				return null
				break
		}
	}

	//清算路径
	onBspt = () => {
		switch (this.model.bopmod_szflg) {
			case 'dbb':
				return (<StepItem title="境外汇款申请书">
					<Dbb model={this.model} extra={this.extra} />
				</StepItem>)
				break;
			case 'dbe':
				return (<StepItem title="境内汇款申请书">
					<Dbe model={this.model} extra={this.extra} />
				</StepItem>)
				break;
			case 'bsb':
				return null
				break;
			default:
				return null
				break
		}
	}
	//报送信息
	onBSXX = () => {
		switch (this.model.rmbmod_rmbflg) {
			case '1':
				return (<StepItem title="报送信息">
					<BaoSong model={this.model} extra={this.extra} />
				</StepItem>)
				break;
			default:
				return null
				break;
		}
	}
	//结售汇申报
	onJsh = () => {
		switch (this.model.jspmod_jshtyp) {
			case '1':
				return (<StepItem title="结汇申报">
					<Dbj model={this.model} extra={this.extra} />
				</StepItem>)
				break;
			case '2':
				return (<StepItem title="购汇申报">
					<Dbw model={this.model} extra={this.extra} />
				</StepItem>)
				break;
			default:
				return null
				break;
		}
	}

	//交易内实现
	renderPage() {
		return (
			<Card title="汇出汇款" size="small" className="transTitle">
				<Steps>
					<StepItem title="概况">
						<Basic model={this.model} extra={this.extra} flag={this.state.flag} />
					</StepItem>
					{this.onBaowen()}
					<StepItem title="费用">
						<Fee model={this.model} extra={this.extra} />
					</StepItem>
					<StepItem title="会计分录">
						<Gle model={this.model} extra={this.extra} />
					</StepItem>
					<StepItem title="申报信息">
						<ShenBao model={this.model} extra={this.extra} />
					</StepItem>
					{/*
					<StepItem title="外管申报">
						<Bspt model={this.model} extra={this.extra} />
					</StepItem>
					*/}
					{this.onBspt()}
					{/* <StepItem title="报送信息">
						<BaoSong model={this.model} extra={this.extra} />
					</StepItem> */}
					{this.onBSXX()}
					{this.onJsh()}
					<StepItem title="面函">
						<Papper model={this.model} extra={this.extra} />
					</StepItem>
				</Steps>
			</Card>
		)
	}
}
