import React,{Component,Fragment} from 'react'
import {Page,Validator,Notification,FormItem,
    InputItem,Input,Bind,SelectItem,Button,Label,Table,Section,DatePickerItem,ConfirmButton} from '@/components/Common-Library'
import {Divider} from 'antd'
import Api from '@/service/api'
import mDbausr from '../model'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { action, observable } from 'mobx'
import { Col, Row,Card } from 'antd'

@inject('UserContext')
@inject('i18n')
@observer
export default class DbausrScreen extends Page
{
    @observable
    formBlur=false

    @observable
    extra = { inifrm: 'dbausr', sptinr: '', usg: [], bchkey:[] }
    
    @observable
    isDisabled=false;

    constructor(props)
    {
        super(props)
        this.model = new mDbausr()
        this.bind = Bind.bind(this)
        this.onSav=this.onSav.bind(this);
    }

    componentWillUnmount()
    {
      this.model.stopMonitor&&this.model.stopMonitor()//关闭校验
    }

    //初始化代码
		async componentWillMount() {
			let sptinr = '';
      let rtnmsg = [];
			if (this.props.location.query) {
				sptinr = this.props.location.query.inr
				this.extra.sptinr = sptinr
				rtnmsg = await Api.post(this.extra.inifrm + '/init', { params: { sptinr } })
			} else {
				rtnmsg = await Api.post(this.extra.inifrm + '/init', {})
			}
			if (rtnmsg.retcod == SUCCESS) {
				Object.assign(this.model, rtnmsg.data)
        this.extra.bchkey = rtnmsg.codetable.bchkey;
        this.extra.usg = rtnmsg.codetable.usg;
			}
			else {
				Notification.error({ message: '服务端请求失败!' })
			}
	
			//快照模式下，不必开启校验，否则，静默校验，和记录变动
			!this.loadDisplay() && this.model.openMonitor() //开启校验	
    }
    
    //按钮事件
	  async onSav(){
        this.formBlur=true  //已触发表单提交处理
        this.isDisabled=true  //点击提交按钮之后禁用，防止多次点击 
        //登录名称重名检核
        if(this.model.nam){
          const rtnmsg=await Api.post('dbausr/check',{params:{nam:this.model.nam},data:this.model})
          if( rtnmsg.retcod == SUCCESS ){
            // let bool = (JSON.stringify(rtnmsg.error) == "{}");
            if(rtnmsg.error.nam){
              Notification.error({message:'登录名称重用!'})
              this.isDisabled=false
              return
            }
          }else{
            Notification.error({message:'服务端请求失败!'})
            this.isDisabled=false
            return
          }
        }

        Validator.validate(this.model, this.model.descriptor, async(errors,values)=>{
                if(errors){
                  this.isDisabled=false
                  return
                }
                const rtnmsg = await Api.post('dbausr/sav',{data:this.model})
                if(rtnmsg.retcod == SUCCESS)
                {
                    Notification.success({message:'提交成功!'});
					          this.props.history.push({pathname:'dblusr', state: {'selflg':true}});
                }
                else
                {
                  Notification.error({message:'服务端请求失败!'})
                  this.isDisabled=false
                }
                //余下逻辑处理     
        })
    }

    onRtn= ()=>{
      	this.props.history.push("dblusr");
    }

    //交易内实现
    renderPage(){
    	const bind = this.bind
        const {i18n} = this.props
        const CodeTable = CodeTableFactory.getInstance()
     
  return (
		<Card title="用户管理" size="small" className="transTitle">
      <div style={{position:'relative'}}>
				<Row>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label i18nId={"USRP_LT000277"}/>	
							</Col>
							<Col span={14}>
								<InputItem InputProps={bind("nam")} />
							</Col>
						</Row>
					</Col>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label i18nId={"USRP_LT000278"}/>
							</Col>
							<Col span={14}>
								<InputItem InputProps={bind("dspnam")} />
							</Col>
						</Row>
					</Col>
				</Row>
				<Row>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label i18nId={"USRP_LT000279"}/>	
							</Col>
							<Col span={14}>
								<SelectItem InputProps={bind("sta")} code={CodeTable.usrsta}  />
							</Col>
						</Row>
					</Col>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
							<Label i18nId={"USRP_LT000280"}/>	
							</Col>
							<Col span={14}>
                <SelectItem InputProps={bind("bchkey")} code={this.extra.bchkey}  />
							</Col>
						</Row>
					</Col>
				</Row>
				
				<Row>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
							<Label i18nId={"USRP_LT000281"}/>	
							</Col>
							<Col span={14}>
								<InputItem InputProps={{type:"password",...bind("pwd")}}  />
							</Col>
						</Row>
					</Col>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
							<Label i18nId={"USRP_LT000282"}/>	
							</Col>
							<Col span={14}>
								<DatePickerItem InputProps={bind("valdat")}/>
							</Col>
						</Row>
					</Col>
				</Row>
				
				<Row>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label i18nId={"USRP_LT000286"}/>	
							</Col>
							<Col span={14}>
								<SelectItem InputProps={bind("usrlvl")} code={CodeTable.usrlvl} />
							</Col>
						</Row>
					</Col>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label i18nId={"USRP_LT000287"}/>	
							</Col>
							<Col span={14}>
								<InputItem InputProps={bind("etyextkey")} />
							</Col>
						</Row>
					</Col>
				</Row>
				<Row>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label i18nId={"USRP_LT000288"}/>	
							</Col>
							<Col span={14}>
								<InputItem InputProps={bind("etaextkey")} />
							</Col>
						</Row>
					</Col>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label i18nId={"USRP_LT000289"}/>	
							</Col>
							<Col span={14}>
                <SelectItem InputProps={bind("usg")} code={this.extra.usg} />
							</Col>
						</Row>
					</Col>
				</Row>	
				<Row>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label i18nId={"USRP_LT000290"}/>	
							</Col>
							<Col span={14}>
								<DatePickerItem InputProps={bind("credat")}/>
							</Col>
						</Row>
					</Col>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label i18nId={"USRP_LT000291"}/>	
							</Col>
							<Col span={14}>
								<InputItem InputProps={bind("fax")} />
							</Col>
						</Row>
					</Col>
				</Row>
				
				<Row>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label i18nId={"USRP_LT000292"}/>	
							</Col>
							<Col span={14}>
								<InputItem InputProps={bind("tel")} />
							</Col>
						</Row>
					</Col>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								<Label i18nId={"USRP_LT000293"}/>	
							</Col>
							<Col span={14}>
								<InputItem InputProps={bind("eml")} />
							</Col>
						</Row>
					</Col>
				</Row>

        <Row type="flex" justify="center">
          <Col>
            <div className="button0">
              <div className='button2'>
                {/* 退出按钮 */}
                <Button type="primary" onClick={this.onRtn}>
                  <Label i18nId="MTABUT_BT000020" />      
                </Button>
              </div>
              <div className='button2'>
                <ConfirmButton
                  type="primary"
                  onOK={this.onSav}
                  icon="save"
                  message="确定提交？"
                  disabled={this.isDisabled}
                >
                  <Label i18nId="MTABUT_BT000473" />
                </ConfirmButton>
              </div>
            </div>
          </Col>
        </Row>
		</div>
		</Card>
		)
	}
}
