import React, { Component, Fragment } from 'react'
import {
    Page, Validator, Notification, FormItem,
    InputItem, Input, Bind, SelectItem, Button, Label, Table, Section, DatePickerItem
} from '@/components/Common-Library'
import { Divider } from 'antd'
import Api from '@/service/api'
import mDblbch from '../model'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { action, observable } from 'mobx'
import { Col, Row ,Card } from 'antd'
import { Link } from 'react-router-dom'
import Moment from 'moment'
const CodeTable = CodeTableFactory.getInstance()

@inject('UserContext')
@inject('i18n')
@observer
export default class DblbchScreen extends Page {
    @observable
    formBlur = false

    constructor(props) {
        super(props)
        this.model = new mDblbch()
        this.bind = Bind.bind(this)
    }

    componentWillUnmount() {
      this.model.stopMonitor&&this.model.stopMonitor()//关闭校验
    }
    
	async componentWillMount() {
		 if (this.props.location.state) {
             let selflg = this.props.location.state.selflg
		     if (selflg)
				this.onSel()
     }	
     //快照模式下，不必开启校验，否则，静默校验，和记录变动
    !this.loadDisplay() && this.model.openMonitor() //开启校验	
	}
	
    bchlstHeader = [
        {
            title: <Label i18nId="BCHP_TH000020" />,
            dataIndex: "branch",
            key: "branch",
            width: 100,
        },
        {
            title: <Label i18nId="BCHP_TH000021" />,
            dataIndex: "lev",
            key: "lev",
            width: 100,
            render: (val, row, index) => {
                let text = val
                let em = CodeTable.bchlev.find(item => item.value == val)
                if (em)
                    text = em.label
                return text
            }

        },
        {
            title: <Label i18nId="BCHP_TH000022" />,
            dataIndex: "namcn",
            key: "namcn",
            width: 100,
        },
        {
            title: <Label i18nId="BCHP_TH000023" />,
            dataIndex: "upbranch",
            key: "upbranch",
            width: 100,
        },
        {
            title: <Label itext="人行支付行号" />,
            dataIndex: "rmbrpt",
            key: "rmbrpt",
            width: 100,
        },
        {
            title: <Label itext="金融机构标识码" />,
            dataIndex: "decnum",
            key: "decnum",
            width: 100,
        },
        {
            title: '操作',
            dataIndex: "op",
            key: "op",
            width: 120,
            render: (val, row, index) => {
                return (
                    <div>
                        <Link to={{ pathname: 'dbebch', query: { inr: row.inr } }}>修改</Link>
                        <Divider type="vertical" />
                        <Link to={{ pathname: 'dbibch', query: { inr: row.inr } }}>明细</Link>
                        <Divider type="vertical" />
                        <Link to={{ pathname: 'dbdbch', query: { inr: row.inr } }}>删除</Link>
                    </div>
                )
            }
        },
    ]

    onAdd = () => {
        this.props.history.push('dbabch')
    }
    onSel = () => {
        this.formBlur = true  //已触发表单提交处理
        Validator.validate(this.model, this.model.descriptor, async (errors, values) => {
            if (errors)
                return
            const rtnmsg = await Api.post('dblbch/sel', { data: this.model })
            if (rtnmsg.retcod == SUCCESS) {
                //Notification.success({message:'数据提交成功!'})
                this.model.bchp_bchlst = rtnmsg.data['bchp_bchlst'];
                console.log(this.model)
            }
            else {
                Notification.error({ message: '查询失败!' })
            }
            //余下逻辑处理

        })
    }


    //交易内实现
    renderPage() {
        const bind = this.bind
        const { i18n } = this.props

        return (
		 <Card title="机构维护" size="small" className="transTitle">
            <div style={{ position: 'relative' }}>
           
                <Row>
                    <Col span={20}>

                        <Row>
                            <Col span={12}>
                                <Row className='row'>
                                    <Col span={5} offset={2}>
                                        <Label i18nId={"BCHP_LT000019"} />
                                    </Col>
                                    <Col span={14}>
                                        <InputItem InputProps={bind("bchp_branch")} />
                                    </Col>
                                </Row>
                            </Col>
                            <Col span={12}>
                                <Row className='row'>
                                    <Col span={5} offset={2}>
                                        <Label itext="中文名称" />
                                    </Col>
                                    <Col span={14}>
                                        <InputItem InputProps={bind("bchp_namcn")} />
                                    </Col>
                                </Row>
                            </Col>
                        </Row>


                    </Col>
                </Row>


                <div className='button0'>
                    <div className='button2'>
                        <Button type="primary" icon="search" onClick={this.onSel}>
                            <Label i18nId="MTABUT_BT000022" />
                        </Button>
                    </div>
                    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
				 <div className='button2'>
                        <Button type="primary" onClick={this.onAdd}>
                            <Label i18nId="MTABUT_BT000182" />
                        </Button>
                    </div>
                </div>

                <Row >
                    <Col span={23} style={{marginLeft:40}}>
                        <Table pagination={{ pageSize: 10, hideOnSinglePage: true }} columns={this.bchlstHeader} dataSource={this.model.bchp_bchlst} />
                    </Col>
                </Row>
              
            </div >
			  </Card>
        )
    }
}
