import React, { Component, Fragment } from 'react'
import {
    Page, Validator, Notification, FormItem,
    InputItem, Input, Bind, SelectItem, Button, Label, Table, Section
} from '@/components/Common-Library'
import { Divider } from 'antd'
import Api from '@/service/api'
import mDblusr from '../model'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { action, observable } from 'mobx'
import { Col, Row } from 'antd'
import { Link } from 'react-router-dom'
import Moment from 'moment'
import {Card} from 'antd'
const CodeTable = CodeTableFactory.getInstance()


@inject('UserContext')
@inject('i18n')
@observer
export default class DblusrScreen extends Page {
    @observable
    formBlur = false

    constructor(props) {
        super(props)
        this.model = new mDblusr()
        this.model.openValidate() //开启校验
        this.bind = Bind.bind(this)
    }

    componentWillUnmount() {
        this.model.closeValidate()//关闭校验
    }
	
	componentWillMount() {
		 if (this.props.location.state) {
             let selflg = this.props.location.state.selflg
		     if (selflg)
				this.onSel()
		 }	
	}

    usrlstHeader = [
        // {
        //     title: <Label i18nId="USRP_TH000294" />,
        //     dataIndex: "inr",
        //     key: "inr",
        //     width: 100,
        // },
        {
            title: <Label i18nId="USRP_TH000271" />,
            dataIndex: "nam",
            key: "nam",
            width: 100,
        },
        {
            title: <Label i18nId="USRP_TH000272" />,
            dataIndex: "dspnam",
            key: "dspnam",
            width: 100,
        },
        {
            title: <Label i18nId="USRP_TH000273" />,
            dataIndex: "bchkey",
            key: "bchkey",
            width: 100,
        },
        {
            title: <Label i18nId="USRP_TH000274" />,
            dataIndex: "tel",
            key: "tel",
            width: 100,
        },
        {
            title: <Label i18nId="USRP_TH000275" />,
            dataIndex: "sta",
            key: "sta",
            width: 100,
            render: (val, row, index) => {
                let text = val
                let em = CodeTable.usrsta.find(item => item.value == val)
                if (em)
                    text = em.label
                return text
            }
        },
        {
            title: <Label i18nId="USRP_TH000270" />,
            dataIndex: "credat",
            key: "credat",
            width: 100,
            render: (val, row, index) => {
                if (val) {
                    let dat = Moment(val).format('YYYY-MM-DD')
                    return dat;
                }
                return val
            }
        },
        {
            title: '操作',
            dataIndex: "op",
            key: "op",
            width: 120,
            render: (val, row, index) => {
                return (
                    <div>
                        <Link to={{ pathname: 'dbeusr', query: { inr: row.inr } }}>修改</Link>
                        <Divider type="vertical" />
                        <Link to={{ pathname: 'dbiusr', query: { inr: row.inr } }}>明细</Link>
                        <Divider type="vertical" />
                        <Link to={{ pathname: 'dbdusr', query: { inr: row.inr } }}>删除</Link>
                    </div>
                )
            }
        },
    ]


    //按钮事件
    onAdd = () => {
        this.props.history.push('dbausr')
    }
    onSel = () => {
        this.formBlur = true  //已触发表单提交处理
        Validator.validate(this.model, this.model.descriptor, async (errors, values) => {
            if (errors)
                return
            const rtnmsg = await Api.post('dblusr/sel', { data: this.model })
            if (rtnmsg.retcod == SUCCESS) {
                //  Notification.success({ message: '数据提交成功!' })
                let str = 'usrlst'
                this.model.usrp_usrlst = rtnmsg.data.usrp_usrlst;
            }
            else {
                Notification.error({ message: '查询失败!' })
            }
            //余下逻辑处理

        })
    }


    //交易内实现
    renderPage() {
        const bind = this.bind
        const { i18n } = this.props
        return (
		<Card title="用户管理" size="small" className="transTitle">
            <div style={{ position: 'relative' }}>

                <Row>
                    <Col span={20}>

                        <Row>
                            <Col span={12}>
                                <Row className='row'>
                                    <Col span={5} offset={2}>
                                        <Label i18nId={"USRP_LT000265"} />
                                    </Col>
                                    <Col span={14}>
                                        <InputItem InputProps={bind("usrp_nam")} />
                                    </Col>
                                </Row>
                            </Col>
                            <Col span={12}>
                                <Row className='row'>
                                    <Col span={5} offset={2}>
                                        <Label i18nId={"USRP_LT000267"} />
                                    </Col>
                                    <Col span={14}>
                                        <InputItem InputProps={bind("usrp_dspnam")} />
                                    </Col>
                                </Row>
                            </Col>
                        </Row>

                        <Row>
                            <Col span={12}>
                                <Row className='row'>
                                    <Col span={5} offset={2}>
                                        <Label i18nId={"USRP_LT000268"} />
                                    </Col>
                                    <Col span={14}>
                                        <SelectItem InputProps={bind("usrp_sta")} code={CodeTable.sta} />
                                    </Col>
                                </Row>
                            </Col>
                        </Row>


                    </Col>
                </Row>

                <div className='button0'>
                    <div className='button2'>
                        <Button type="primary" icon="search" onClick={this.onSel}>
                            <Label i18nId="MTABUT_BT000022" />
                        </Button>
                    </div>
                    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
					 <div className='button2'>
                        <Button type="primary" onClick={this.onAdd}>
                            <Label i18nId="MTABUT_BT000182" />
                        </Button>
                    </div>
                </div>
                <Row >
                    <Col span={23} style={{ marginLeft: 40 }}>
                        <Table pagination={{ pageSize: 10, hideOnSinglePage: true }} columns={this.usrlstHeader} dataSource={this.model.usrp_usrlst} />
                    </Col>
                </Row>
            </div>
			</Card>
        )
    }
}
