import React, { Component, Fragment } from 'react'
import {
	Page, Validator, Notification, FormItem,
	InputItem, Input, Bind, SelectItem, Button, Label, DatePickerItem, Section, ConfirmButton, Steps, TextAreaItem
} from '@/components/Common-Library'
import Api from '@/service/api'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { action, observable, autorun } from 'mobx'
import { Row, Col, Popconfirm, Modal, Spin } from 'antd';
import { PtyPicker } from '@/components/Business-Library'
import { Link, withRouter } from 'react-router-dom'
import Ptspta1 from '@/views/Public/Ptspta1'
import Business from '@/views/Public/Business'
import moment from 'moment';

const { Pre, Next, StepWrapper } = Steps
const CodeTable = CodeTableFactory.getInstance()
const confirm = Modal.confirm

@withRouter
@inject('UserContext')
@inject('i18n')
@observer
export default class OvwpScreen extends Page {
	@observable
	formBlur = false

	constructor(props) {
		super(props)
		this.model = props.model
		this.bind = Bind.bind(this)
	}
	//交易描述赋值
	componentDidMount() {
		super.componentDidMount()
		this.autoDispose = autorun(() => {
			this.model.nam = `${this.model.nom1_cur}   ${this.model.max_amt}   ${this.model.pts3_namcn || ""}`
			this.model.max_amt = (this.model.nom1_amt * (1 + this.model.nomtop / 100)).toFixed(2) //最大金额计算
			if (this.model.avbby == 'SIGT') {
				this.model.tenmaxday = ''
				//Validator.validate(this.model, this.model.descriptor
			}
		})
	}
	componentWillUnmount() {
		this.autoDispose && this.autoDispose()
	}

	onTabFocus() {
		console.log('#我被选中#')
	}


	onTabBlur() {
		//this.goNext();
		console.log('#我已离开#')
	}
	//按钮事件 获取业务编号
	onGetref = async () => {
		const rtnmsg = await Api.post(this.props.extra.inifrm + '/getref', { data: this.model })
		if (rtnmsg.retcod == SUCCESS) {
			// Notification.success({ message: 'cptopn/mtabut/getref数据提交成功!' })
			this.model.ownref = rtnmsg.data.ownref;
		}
		else {
			Notification.error({ message: '请求失败!' })
		}
		//余下逻辑处理
	}

	  //控制开立日期选择范围
	  dateDisabled=(time)=>{
		return time && time > moment();
	  }
	
	// 退出按钮
	onRtn = async () => {
		this.com.wrappedInstance.wrappedInstance.onRtn();
	}
	// 暂存按钮
	onPed = async () => {
		this.com.wrappedInstance.wrappedInstance.onPed();
	}
	// 校验 按钮
	onChk = () => {
		this.com.wrappedInstance.wrappedInstance.onChk();
	}

	onSav = () => {
		this.com.wrappedInstance.wrappedInstance.onSav();
	}

  //根据远期付款期限自动获取有效日期
  getExpdat = ()=>{
    let opndat = moment( this.model.opndat ).format( 'YYYY-MM-DD' );
    let tenmaxday = this.model.tenmaxday
    if(opndat && tenmaxday){
      let expdat = moment(opndat).add(tenmaxday,'day')  //计算N天之后的日期
      this.model.expdat = moment( expdat ).format( 'YYYY-MM-DD' )   //格式化日期
    }
  }

	//交易内实现
	renderPage() {
		const bind = this.bind
		const { i18n } = this.props
		const { bchlevelLst } = this.props.extra
		  //将模型变量绑定到页签的bindSet对象中，才能在检核的时候被检查到变量所在页签，继而跳转到对应页签
		  bind("pts3_namcn")
		  bind("pts4_namcn")
		  bind("pts1_namcn")

		//const {next,pre} = this.props.steps
		if (this.props.flag == true) {
			return <Spin style={{ width: "100%", justifyContent: "center" }} spinning={this.props.flag} />
		}
		return (
			<div style={{ position: 'relative' }}>
				<Business wrappedComponentRef={ref => (this.com = ref)} page={this} extra={this.props.extra} steps={this.props.steps} model={this.model} />
				{/* 第一行 */}
				<Row>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								{/* 业务编号 */}
								<Label itext="业务编号" />
							</Col>
							<Col span={10}>
								<InputItem InputProps={bind("ownref")} maxLength={16} disabled={true} desp="业务编号" path="/didgrp/rec/ownref" />
							</Col>
							<Col span={4} offset={1}>
								<Button type="primary" onClick={this.onGetref} desp="Get Ref." path="/mtabut/getref">
									<Label itext="获取" />
								</Button>
							</Col>
						</Row>
					</Col>
					<Col span={12}>
						<Row className="row">
							<Col span={5} offset={2}>
								{/* 概要描述 */}
								<Label itext="概要描述" />
							</Col>
							<Col span={14}>
								<InputItem InputProps={bind("nam")} disabled={true} maxLength={40} desp="概要描述" path="/didgrp/rec/nam" />
							</Col>
						</Row>
					</Col>

				</Row>
				{/* 第二行 */}
				<Row>
					<Col span={12}>
						<Col span={24}>
							<Row className="row" >
								<Col span={5} offset={2}>
									{/* 归属机构*/}
									<Label itext="归属机构" />
								</Col>
								<Col span={14}>
									<SelectItem InputProps={bind("ownbch")} code={bchlevelLst} desp="归属机构" path="/didgrp/rec/ownbch" />
								</Col>

							</Row>
						</Col>
						<Col span={24}>
							<Row className="row">
								<Col span={5} offset={2}>
									{/* 归属机构*/}
									<Label itext="客户经理" />
								</Col>
								<Col span={14}>
									<InputItem InputProps={bind("accusr")} maxLength={8} desp="客户经理" path="/didgrp/rec/accusr" />
								</Col>
							</Row>
						</Col>
						<Col span={24}>
							<Row className="row">
								<Col span={5} offset={2}>
									{/* 清算路径 */}
									<Label itext="开立日期" />
								</Col>
								<Col span={10}>
									<DatePickerItem InputProps={bind("opndat")} desp="开立日期" path="/didgrp/rec/opndat" dateDisabled={this.dateDisabled}/>
								</Col>
							</Row>
						</Col>
					</Col>
					<Col span={12}>
						<Ptspta1 model={this.model} argArr={{ desc: "申请人", prefix: 'pts3', url: 'ditopn/aplp_ptysel', flg: 'C', datakey: '\\ditp\\aplp\\ptslst' }} formBlur={this.formBlur}/>
					</Col>

				</Row>
				{/* 第三行 */}
				<Row>
					<Col span={12}>
						<Row className="row" >
							<Col span={5} offset={2}>
								{/* 信用证金额 */}
								<Label itext="信用证金额" />
							</Col>
							<Col span={6}>
								<SelectItem InputProps={{
									...bind("nom1_cur"), onChange: val => {
										this.model.nom1_cur = val
										this.model.liqtyp = ""
										this.model.swftyp = ""
									}
								}}
									disabled={true} code={CodeTable.curtxt} />
							</Col>
							<Col span={7} offset={1}>
								<InputItem   InputProps={ {...bind("nom1_amt"), type:"amount", cur:this.model.nom1_cur} } />
							</Col>
						</Row>
					</Col>
					<Col span={12}>
						<Row className="row">

							<Col span={5} offset={2}>
								{/* 申请人账号 */}
								<Label itext="申请人账号" />
							</Col>
							<Col span={14}>
								<InputItem InputProps={bind("pts3_extact")} maxLength={32} desp="结算账号" path="/didgrp/apl/pts/extact" />
							</Col>

						</Row>

					</Col>
				</Row>

				<Row>
					<Col span={12}>
						<Col span={24}>
							<Row className="row">
								<Col span={5} offset={2}>
									{/* 上下浮动比例+/-% */}
									<Label itext="上下浮动比例+/-%" />
								</Col>
								<Col span={6}>
									<InputItem InputProps={bind("nomtop")} desp="上浮" path="/didgrp/rec/nomtop" />
								</Col>
								<Col span={1} offset={1}>
									<Label itext="/" />
								</Col>
								<Col span={6}>
									<InputItem InputProps={bind("nomton")} desp="下浮" path="/didgrp/rec/nomton" />
								</Col>
							</Row>
						</Col>
						<Col span={24}>
							<Row className="row">
								<Col span={5} offset={2}>
									{/* 信用证最大金额 */}
									<Label itext="信用证最大金额" />
								</Col>
								<Col span={6}>
									<SelectItem InputProps={{
										...bind("max_cur"), onChange: val => {
											this.model.max_cur = val
											this.model.liqtyp = ""
											this.model.swftyp = ""
										}
									}}
										disabled={true} code={CodeTable.curtxt} />
								</Col>
								<Col span={7} offset={1}>
									<InputItem   InputProps={ {...bind("max_amt"), type:"amount", cur:this.model.max_cur} } />
								</Col>
							</Row>
						</Col>
						<Col span={24}>
							<Row className="row">

								<Col span={5} offset={2}>

									<Label itext="开证类型" />
								</Col>
								<Col span={14}>
								<SelectItem InputProps={{...bind("isstyp"),
                    onAfterChange:(val)=>{
                      if(val=='OWIS' || !val){
												this.model.pts2_extkey="";
												this.model.pts2_namcn="";
												this.model.pts2_adrcn="";
											}
                    }}}  code={CodeTable.isstyp} desp="开证类型" path="/didgrp/rec/isstyp" />
								</Col>
							</Row>
						</Col>
					</Col>

						<Col span={12}>
							{/* 
						<Col span={5} offset={2}>
						
							<Label itext="申请人账号" />
						</Col>
						<Col span={14}>
							<InputItem InputProps={bind("pts1_extact")} maxLength={32} desp="结算账号" path="/didgrp/apl/pts/extact" />
						</Col> */}
							<Col span={3}>

							</Col>

							<Ptspta1 model={this.model} argArr={{ desc: "受益人", prefix: 'pts4', url: 'ditopn/benp_ptysel', flg: 'C', datakey: '\\ditp\\benp\\ptslst' }} formBlur={this.formBlur} />
						</Col>
				</Row >
					{/* 第四行 */}
					<Row>
						<Col span={12}>
							<Row className="row" >
								<Col span={5} offset={2}>
									{/* 贸易方式 */}
									<Label itext="贸易方式" />
								</Col>
								<Col span={14}>
									<SelectItem InputProps={bind("trdtyp")} code={CodeTable.trdtyp} desp="贸易方式" path="/didgrp/rec/trdtyp" />
								</Col>
							</Row>
						</Col>
						<Col span={12}>
							<Row className="row">

								<Col span={5} offset={2}>
									{/* 收益人账号 */}
									<Label itext="受益人账号" />
								</Col>
								<Col span={14}>
									<InputItem InputProps={bind("pts4_extact")} maxLength={32} desp="结算账号" path="/didgrp/ben/pts/extact" />
								</Col>
							</Row>
						</Col>
					</Row>
					{/* 第五行 */}
					<Row>
						<Col span={12}>
							<Col span={24}>
								<Row className="row">

									<Col span={5} offset={2}>

										<Label itext="最迟货物装运日期" />
									</Col>
									<Col span={6}>
										<DatePickerItem InputProps={bind("shpdat")} desp="最迟货物装运/服务提供日期 " path="/didgrp/rec/shpdat" />
									</Col>
								</Row>
							</Col>
							<Col span={24}>
								<Row className="row">

									<Col span={5} offset={2}>
										{/* 信用证兑付方式 */}
										<Label itext="信用证兑付方式" />
									</Col>
									<Col span={7}>
										<SelectItem InputProps={bind("avbby")} code={CodeTable.avbby} desp="信用证兑付方式" path="/didgrp/rec/avbby" />
									</Col>
									<Col span={4} offset={1}>
										<InputItem InputProps={{...bind("tenmaxday"), onBlur:this.getExpdat }} disabled={this.model.avbby == 'SIGT' ? true : false}
											desp="期限" path="/didgrp/rec/tenmaxday" />

									</Col>
									<Col span={4} offset={1}>
										<Label itext="天" />
									</Col>
								</Row>
							</Col>

							<Col span={24}>
								<Row className="row">
									<Col span={24}>

										<Col span={5} offset={2}>
											{/* 有效日期 */}
											<Label itext="有效日期" />
										</Col>
										<Col span={14}>
											<DatePickerItem InputProps={bind("expdat")} desp="有效日期" path="/didgrp/rec/expdat" />

										</Col>
									</Col>
								</Row>
							</Col>
						</Col>

						<Col span={12}>

							<Ptspta1 model={this.model} argArr={{ desc: "通知行", prefix: 'pts1', url: 'ditopn/advp_ptysel', flg: 'B', datakey: '\\ditp\\advp\\ptslst' }} formBlur={this.formBlur} />
						</Col>
					</Row>

					{/* <Row>
					<Col span={12}>
					</Col>

				</Row> */}

					{/* 第六行 */}

					<Row>
						<Col span={12}>
							<Row className="row">
								<Col span={5} offset={2}>
									{/* 远期付款指示 */}
									<Label itext="远期付款指示" />
								</Col>
								<Col span={14}>
									<TextAreaItem InputProps={bind("defdet")} rows={1} style={{ resize: "none" }} code={CodeTable.avbby} desp="远期付款指示" path="/didgrp/rec/defdet" />
								</Col>


							</Row>
						</Col>
					</Row>



					<Row type="flex" justify="center">
						<Col>
							<div className='button0'>
								<div className='button2'>
									{/* 退出按钮 */}
									<ConfirmButton
										onOK={this.onRtn}
										title=""
										message="确定退出？"
									>
										<Label i18nId="MTABUT_BT000464" />
									</ConfirmButton>
								</div>
								<div className='button2'>
									{/* 暂存按钮 */}
									<ConfirmButton
										onOK={this.onPed}
										title=""
										message="确定暂存？"
									>
										<Label i18nId="MTABUT_BT000398" />
									</ConfirmButton>
								</div>
								<div className='button2'>
									{/* 检核按钮 */}
									<Button onClick={this.onChk}>
										<Label i18nId="MTABUT_BT000180" />
									</Button>
								</div>
								<div className='button2'>
									<ConfirmButton icon="save"
										onOK={this.onSav}>
										<Label i18nId="MTABUT_BT000473" />
									</ConfirmButton>
								</div>


							</div>
						</Col>
					</Row>
			</div >
				)
			}
		}
