import React, { Component, Fragment } from 'react'
import {
    Page, Validator, Notification, FormItem, DatePickerItem, TextAreaItem, CheckboxItem,
    InputItem, Input, Bind, SelectItem, Button, Label, Image, Table
} from '@/components/Common-Library'
import Api from '@/service/api'
import mTctrel from '../model'
import CodeTableFactory from '@/components/CodeTable'
import "./index.less"
import { inject, observer } from 'mobx-react'
import { action, observable } from 'mobx'
import { Row, Col, Card } from 'antd'


const CodeTable = CodeTableFactory.getInstance()


@inject('UserContext')
@inject('i18n')
@observer
export default class TctrelScreen extends Page {
    @observable
    formBlur = false

    constructor(props) {
        super(props)
        this.model = new mTctrel()
        this.bind = Bind.bind(this)
    }

    async componentWillMount() {
		/*
		*添加初始化代码
        */
        if (this.props.location.query) {
            console.log(this.props.location.query)
            let inr = this.props.location.query.inr
            const rtnmsg = await Api.post('tctrel/init', { params: { inr } })
            if (rtnmsg.retcod == SUCCESS) {
                console.log("rtnmsg.data");
                console.log(rtnmsg.data);
                console.log("this.model");
                console.log(this.model);
                Object.assign(this.model, rtnmsg.data)
                // this.bchlevelLst = rtnmsg.codetable['bchkey'];
            }
            else {
                Notification.error({ message: '服务端请求失败!' })
            }
        }
        console.log(this.model)
        //快照模式下，不必开启校验，否则，静默校验，和记录变动
        !this.loadDisplay() && this.model.openMonitor() //开启校验	
    }
    componentWillUnmount() {
        this.model.stopMonitor()//关闭校验
    }



    //按钮事件
    onAgree = async () => {
        const rtnmsg = await Api.post('tctrel/agree', { data: this.model })
        if (rtnmsg.retcod == SUCCESS) {
            Notification.success({ message: '数据提交成功!' })

        }
        else {
            Notification.error({ message: '服务端请求失败!' })
        }
        //余下逻辑处理


        // this.formBlur = true  //已触发表单提交处理
        // Validator.validate(this.model, this.model.descriptor, async (errors, values) => {
        //     if (errors)
        //         return
        //     const rtnmsg = await Api.post('tctrel/agree', { data: this.model })
        //     if (rtnmsg.retcod == SUCCESS) {
        //         Notification.success({ message: '数据提交成功!' })

        //     }
        //     else {
        //         Notification.error({ message: '服务端请求失败!' })
        //     }
        //     //余下逻辑处理

        // })
    }
    onGetref = () => {
        this.formBlur = true  //已触发表单提交处理
        Validator.validate(this.model, this.model.descriptor, async (errors, values) => {
            if (errors)
                return
            const rtnmsg = await Api.post('tctrel/getref', { data: this.model })
            if (rtnmsg.retcod == SUCCESS) {
                // Notification.success({ message: '数据提交成功!' })
                this.model.ownref = rtnmsg.data.ownref;
            }
            else {
                Notification.error({ message: '服务端请求失败!' })
            }
            //余下逻辑处理

        })
    }
    onRtn = () => {
        this.props.history.goBack();
    }
    onDisagree = () => {
        this.formBlur = true  //已触发表单提交处理
        console.log(this.model)
        Validator.validate(this.model, this.model.descriptor, async (errors, values) => {
            if (errors)
                return
            const rtnmsg = await Api.post('tctrel/disagree', { data: this.model })
            if (rtnmsg.retcod == SUCCESS) {
                Notification.success({ message: '数据提交成功!' })

            }
            else {
                Notification.error({ message: '服务端请求失败!' })
            }
            //余下逻辑处理

        })
    }


    //交易内实现
    renderPage() {
        const bind = this.bind
        const { i18n } = this.props

        return (
            <Card title="头寸审核" size="small" className="transTitle">
                <div style={{ position: 'relative' }}>

                    <Row >
                        <Col span={12}>
                            <Row className='row'>
                                <Col span={5} offset={2}>
                                    <Label itext="头寸编号" />
                                </Col>
                                <Col span={11}>
                                    <InputItem disabled={true} InputProps={bind("ownref")} maxLength={16} desp="头寸编号" path="/tcsgrp/rec/ownref" />
                                </Col>
                                <Col span={2} offset={1}>
                                    <Button disabled={true} type="primary" onClick={this.onGetref} desp="Get Ref." path="/mtabut/getref">
                                        <Label itext="获取" />
                                    </Button>
                                </Col>
                            </Row>
                        </Col>
                        <Col span={12}>
                            <Row className='row'>
                                <Col span={5} offset={2}>
                                    <Label itext="归属机构" />
                                </Col>
                                <Col span={14}>
                                    <InputItem disabled={true} InputProps={bind("branch")} maxLength={8} desp="归属机构" path="/tcsgrp/rec/branch" />
                                </Col>
                            </Row>
                        </Col>
                    </Row>
                    <Row>
                        <Col span={12}>
                            <Row className='row'>
                                <Col span={5} offset={2}>
                                    <Label itext="机构名称" />
                                </Col>
                                <Col span={14}>
                                    <InputItem disabled={true} InputProps={bind("branchnam")} maxLength={40} desp="机构名称" path="/tcsgrp/rec/branchnam" />
                                </Col>
                            </Row>
                        </Col>
                        <Col span={12}>
                            <Row className='row'>
                                <Col span={5} offset={2}>
                                    <Label itext="申请日期" />
                                </Col>
                                <Col span={14}>
                                    <DatePickerItem InputProps={{ ...bind("credat"), disabled: true }} desp="申请日期" path="/tcsgrp/rec/credat" />
                                </Col>
                            </Row>
                        </Col>
                    </Row>
                    <Row>
                        <Col span={12}>
                            <Row className='row'>
                                <Col span={5} offset={2}>
                                    <Label itext="币种" />
                                    <Label itext="金额" />
                                </Col>
                                <Col span={6}>
                                    <SelectItem InputProps={{ ...bind("cur"), disabled: true }} code={CodeTable.curtxt} desp="币种" path="/tcsgrp/rec/cur" />
                                </Col>
                                <Col span={7} offset={1}>
                                    <InputItem disabled={true} InputProps={bind("amt")} desp="金额" path="/tcsgrp/rec/amt" />
                                </Col>
                            </Row>
                        </Col>
                        <Col span={12}>
                            <Row className='row'>
                                <Col span={5} offset={2}>
                                    <Label itext="预算起息日" />
                                </Col>
                                <Col span={14}>
                                    <DatePickerItem InputProps={{ ...bind("valdat"), disabled: true }} desp="预算起息日" path="/tcsgrp/rec/valdat" />
                                </Col>
                            </Row>
                        </Col>
                    </Row>
                    <Row>
                        <Col span={12}>
                            <Row className='row'>
                                <Col span={5} offset={2}>
                                    <Label itext="审批通过日期" />
                                </Col>
                                <Col span={14}>
                                    <DatePickerItem disabled={true} InputProps={{ ...bind("opndat"), disabled: true }} desp="审批通过日期" path="/tcsgrp/rec/opndat" />
                                </Col>
                            </Row>
                        </Col>
                        <Col span={12}>
                            <Row className='row'>
                                <Col span={5} offset={2}>
                                    <Label itext="状态" />
                                </Col>
                                <Col span={14}>
                                    <SelectItem InputProps={{ ...bind("sta"), disabled: true }} code={CodeTable.tcssta} desp="状态" path="/tcsgrp/rec/sta" />
                                </Col>
                            </Row>
                        </Col>
                    </Row>
                    <Row>
                        <Col span={12}>
                            <Row className='row'>
                                <Col span={5} offset={2}>
                                    <Label itext="账户行BIC" />
                                </Col>
                                <Col span={14}>
                                    <InputItem disabled={true} InputProps={bind("actbnk")} maxLength={12} desp="账户行BIC" path="/tcsgrp/rec/actbnk" />
                                </Col>
                            </Row>
                        </Col>
                        <Col span={12}>
                            <Row className='row'>
                                <Col span={5} offset={2}>
                                    <Label itext="账户号名称" />
                                </Col>
                                <Col span={14}>
                                    <InputItem disabled={true} InputProps={bind("actbnknam")} maxLength={40} desp="账户号名称" path="/tcsgrp/rec/actbnknam" />
                                </Col>
                            </Row>
                        </Col>
                    </Row>
                    <Row>
                        <Col span={12}>
                            <Row className='row'>
                                <Col span={5} offset={2}>
                                    <Label itext="客户名称" />
                                </Col>
                                <Col span={14}>
                                    <InputItem disabled={true} InputProps={bind("cusnam")} maxLength={60} desp="客户名称" path="/tcsgrp/rec/cusnam" />
                                </Col>
                            </Row>
                        </Col>
                        <Col span={12}>
                            <Row className='row'>
                                <Col span={5} offset={2}>
                                    <Label itext="付汇原因" />
                                </Col>
                                <Col span={14}>
                                    <TextAreaItem disabled={true} InputProps={bind("payinf")} desp="付汇原因" path="/tcsgrp/rec/payinf" />
                                </Col>
                            </Row>
                        </Col>
                    </Row>
                    <Row>
                        <Col span={12}>
                            <Row className='row'>
                                <Col span={5} offset={2}>
                                    <Label itext="款项来源" />
                                </Col>
                                <Col span={14}>
                                    <TextAreaItem disabled={true} InputProps={bind("payifom")} desp="款项来源" path="/tcsgrp/rec/payifom" />
                                </Col>
                            </Row>
                        </Col>
                        <Col span={12}>
                            <Row className='row'>
                                <Col span={5} offset={2}>
                                    <Label itext="退回原因" />
                                </Col>
                                <Col span={14}>
                                    <TextAreaItem InputProps={bind("rtnmsg")} desp="退回原因" path="/tcsgrp/rec/rtnmsg" />
                                </Col>
                            </Row>
                        </Col>
                    </Row>

                    {/* 
                    <InputItem InputProps={bind("branch")} maxLength={8} desp="归属机构" path="/tcsgrp/rec/branch" />
                    <InputItem InputProps={bind("branchnam")} maxLength={40} desp="机构名称" path="/tcsgrp/rec/branchnam" />
                    <InputItem InputProps={bind("ownref")} maxLength={16} desp="头寸编号" path="/tcsgrp/rec/ownref" />
                    <Button type="primary" onClick={this.onGetref} desp="Get Ref." path="/mtabut/getref">
                        <Label itext="获取" />
                    </Button>
                    <DatePickerItem InputProps={bind("credat")} desp="申请日期" path="/tcsgrp/rec/credat" />
                    <SelectItem InputProps={bind("cur")} code={CodeTable.curtxt} desp="币种" path="/tcsgrp/rec/cur" />
                    <InputItem InputProps={bind("amt")} desp="金额" path="/tcsgrp/rec/amt" />
                    <DatePickerItem InputProps={bind("valdat")} desp="预算起息日" path="/tcsgrp/rec/valdat" />
                    <DatePickerItem InputProps={bind("opndat")} desp="审批通过日期" path="/tcsgrp/rec/opndat" />
                    <InputItem InputProps={bind("sta")} maxLength={1} desp="状态" path="/tcsgrp/rec/sta" />
                    <InputItem InputProps={bind("actbnk")} maxLength={12} desp="账户行BIC" path="/tcsgrp/rec/actbnk" />
                    <InputItem InputProps={bind("actbnknam")} maxLength={40} desp="账户号名称" path="/tcsgrp/rec/actbnknam" />
                    <InputItem InputProps={bind("cusnam")} maxLength={60} desp="客户名称" path="/tcsgrp/rec/cusnam" />
                    <TextAreaItem InputProps={bind("payinf")} desp="付汇原因" path="/tcsgrp/rec/payinf" />
                    <TextAreaItem InputProps={bind("payifom")} desp="款项来源" path="/tcsgrp/rec/payifom" />
                    <TextAreaItem InputProps={bind("rtnmsg")} desp="退回原因" path="/tcsgrp/rec/rtnmsg" /> 
                    */}
                    <div style={{ textAlign: "center" }}>
                        <Button style={{ marginLeft: 10, marginRight: 10 }} type="primary" onClick={this.onAgree} desp="通过" path="/agree">
                            <Label itext="通过" />
                        </Button>
                        <Button style={{ marginLeft: 10, marginRight: 10 }} type="primary" onClick={this.onDisagree} desp="退回" path="/disagree">
                            <Label itext="退回" />
                        </Button>
                        <Button style={{ marginLeft: 10, marginRight: 10 }} type="primary" onClick={this.onRtn} desp="返回" path="/rtn">
                            <Label itext="返回" />
                        </Button>
                    </div>
                    {/* <Label itext="归属机构" />
                    <Label itext="机构名称" />
                    <Label itext="头寸编号" />
                    <Label itext="申请日期" />
                    <Label itext="币种" />
                    <Label itext="金额" />
                    <Label itext="预算起息日" />
                    <Label itext="审批通过日期" />
                    <Label itext="状态" />
                    <Label itext="账户行BIC" />
                    <Label itext="账户号名称" />
                    <Label itext="客户名称" />
                    <Label itext="付汇原因" />
                    <Label itext="款项来源" />
                    <Label itext="退回原因" /> 
                    */}
                </div>
            </Card>
        )
    }
}
